# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-05-04 02:53
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('glossary', '0002_auto_20170314_0850'),
    ]

    operations = [
        migrations.AlterField(
            model_name='academicgroup',
            name='year',
            field=models.SmallIntegerField(choices=[(1, 'Первый'), (2, 'Второй'), (3, 'Третий'), (4, 'Четвертый'), (5, 'Пятый'), (6, 'Шестой')], default=1, verbose_name='Курс'),
        ),
    ]
