# Generated by Django 2.1.5 on 2019-02-04 08:53

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('glossary', '0005_auto_20190131_0942'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='room',
            options={'verbose_name': 'Помещение', 'verbose_name_plural': 'Помещения'},
        ),
    ]
