# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-14 06:07
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import uuid


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='AcademicGroup',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('uuid', models.UUIDField(default=uuid.uuid4, editable=False, unique=True)),
                ('name', models.CharField(max_length=127, verbose_name='Название')),
                ('year', models.SmallIntegerField(choices=[(1, 'Первый'), (2, 'Второй'), (3, 'Третий'), (4, 'Четвертый'), (5, 'Пятый')], default=1, verbose_name='Курс')),
            ],
            options={
                'verbose_name_plural': 'Академические группы',
                'verbose_name': 'Академическая группа',
            },
        ),
        migrations.CreateModel(
            name='Department',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('uuid', models.UUIDField(default=uuid.uuid4, editable=False, unique=True)),
                ('name', models.CharField(max_length=127, verbose_name='Название')),
            ],
            options={
                'verbose_name_plural': 'Кафедры',
                'verbose_name': 'Кафедра',
            },
        ),
        migrations.CreateModel(
            name='Faculty',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('uuid', models.UUIDField(default=uuid.uuid4, editable=False, unique=True)),
                ('name', models.CharField(max_length=127, verbose_name='Название')),
            ],
            options={
                'verbose_name_plural': 'Факультеты',
                'verbose_name': 'Факультет',
            },
        ),
        migrations.AddField(
            model_name='department',
            name='faculty',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='glossary.Faculty', verbose_name='Факультет'),
        ),
        migrations.AddField(
            model_name='academicgroup',
            name='faculty',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='glossary.Faculty', verbose_name='Факультет'),
        ),
    ]
